@@ -1,44 +1,33 @@
-/******************************************************************************
-*   Copyright 2007-2011 by Aaron Seigo <aseigo@kde.org>                       *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2011 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PLASMA_PACKAGE_H
 #define PLASMA_PACKAGE_H
 
 #include <QStringList>
 
-#include <KPluginInfo>
-
 #include <plasma/plasma.h>
 #include <plasma/plasma_export.h>
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 94)
+#include <KPluginInfo>
+#endif
+
 class KJob;
 
 // not 5.6, as last Plasma API using this class only got removed later
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 28)
 
-namespace KPackage {
-    class Package;
+namespace KPackage
+{
+class Package;
 }
 
 namespace Plasma
 {
-
 /**
  * @class Package plasma/package.h <Plasma/Package>
  *
@@ -79,7 +68,7 @@ namespace Plasma
  *
  * @deprecated Since 5.6, use KPackage::Package instead
  **/
-//TODO: write documentation on USING a package
+// TODO: write documentation on USING a package
 
 class PackagePrivate;
 class PackageStructure;
@@ -206,8 +195,8 @@ public:
     bool allowExternalPaths() const;
 
     /**
-      * @return the package metadata object.
-      */
+     * @return the package metadata object.
+     */
     KPluginInfo metadata() const;
 
     /**
@@ -379,6 +368,4 @@ Q_DECLARE_METATYPE(Plasma::Package)
 
 #endif // PLASMA_ENABLE_DEPRECATED_SINCE(5, 28)
 
-
 #endif
-
