@@ -1,40 +1,27 @@
 /*
- *   Copyright 2006-2007 Aaron Seigo <aseigo@kde.org>
- *   Copyright 2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2006-2007 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PLASMA_THEME_H
 #define PLASMA_THEME_H
 
-#include <QGuiApplication>
 #include <QFont>
+#include <QGuiApplication>
 #include <QObject>
 
-#include <kplugininfo.h>
-#include <ksharedconfig.h>
-
 #include <plasma/plasma_export.h>
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 94)
+#include <KPluginInfo>
+#endif
+#include <KSharedConfig>
 
 class KPluginMetaData;
 
 namespace Plasma
 {
-
 class ThemePrivate;
 class SvgPrivate;
 
@@ -60,7 +47,7 @@ class PLASMA_EXPORT Theme : public QObject
     Q_PROPERTY(bool useGlobalSettings READ useGlobalSettings NOTIFY themeChanged)
     Q_PROPERTY(QString wallpaperPath READ wallpaperPath NOTIFY themeChanged)
 
-    //fonts
+    // fonts
     Q_PROPERTY(QFont defaultFont READ defaultFont NOTIFY defaultFontChanged)
     Q_PROPERTY(QFont smallestFont READ smallestFont NOTIFY smallestFontChanged)
 
@@ -79,18 +66,20 @@ public:
         FocusColor = 4, /**< color for focus effect on view */
         LinkColor = 5, /**< color for clickable links */
         VisitedLinkColor = 6, /**< color visited clickable links */
-        HighlightedTextColor = 7,/**< color contrasting with HighlightColor, to be used for instance with */
+        HighlightedTextColor = 7, /**< color contrasting with HighlightColor, to be used for instance with */
         PositiveTextColor = 8, /**< color of foreground objects with a "positive message" connotation (usually green) */
         NeutralTextColor = 9, /**< color of foreground objects with a "neutral message" connotation (usually yellow) */
         NegativeTextColor = 10, /**< color of foreground objects with a "negative message" connotation (usually red) */
-        DisabledTextColor = 11 /**< color of disabled text @since 5.64 */
+        DisabledTextColor = 11, /**< color of disabled text @since 5.64 */
     };
 
     enum ColorGroup {
         NormalColorGroup = 0,
         ButtonColorGroup = 1,
         ViewColorGroup = 2,
-        ComplementaryColorGroup = 3
+        ComplementaryColorGroup = 3,
+        HeaderColorGroup,
+        ToolTipColorGroup,
     };
     Q_ENUM(ColorGroup)
 
@@ -108,7 +97,7 @@ public:
      */
     explicit Theme(const QString &themeName, QObject *parent = nullptr);
 
-    ~Theme();
+    ~Theme() override;
 
     /**
      * Sets the current theme being used.
@@ -232,6 +221,10 @@ public:
      * @param lastModified if non-zero, the time stamp is also checked on the file,
      *                     and must be newer than the timestamp to be loaded
      *
+     * @note Since KF 5.75, a lastModified value of 0 is deprecated. If used, it
+     *       will now always return false. Use a proper file timestamp instead
+     *       so modification can be properly tracked.
+     *
      * @return true when pixmap was found and loaded from cache, false otherwise
      * @since 4.3
      **/
@@ -277,6 +270,7 @@ public:
      **/
     void setCacheLimit(int kbytes);
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 78)
     /**
      * Tries to load the rect of a sub element from a disk cache
      *
@@ -286,6 +280,7 @@ public:
      *           if not found or if we are sure it doesn't exist it will be QRect()
      * @return true if the element was found in cache or if we are sure the element doesn't exist
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     bool findInRectsCache(const QString &image, const QString &element, QRectF &rect) const;
 
     /**
@@ -297,6 +292,7 @@ public:
      *
      * @since 4.6
      */
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     QStringList listCachedRectKeys(const QString &image) const;
 
     /**
@@ -306,6 +302,7 @@ public:
      * @param element sub element we want insert the rect
      * @param rect element rectangle
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void insertIntoRectsCache(const QString &image, const QString &element, const QRectF &rect);
 
     /**
@@ -313,6 +310,7 @@ public:
      *
      * @param image the path to the image the cache is associated with
      **/
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void invalidateRectsCache(const QString &image);
 
     /**
@@ -322,7 +320,9 @@ public:
      *
      * @param image the path to the image the cache is associated with
      */
+    PLASMA_DEPRECATED_VERSION(5, 78, "Rects Cache public API is deprecated")
     void releaseRectsCache(const QString &image);
+#endif
 
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 67)
     /**
@@ -337,9 +337,9 @@ public:
 #endif
 
     /**
-     * @return metadata for this theme, with information such as
+     * @return plugin metadata for this theme, with information such as
      * name, description, author, website etc
-     * @since 5.67
+     * @since 5.95
      */
     KPluginMetaData metadata() const;
 
@@ -373,6 +373,21 @@ public:
      */
     bool backgroundContrastEnabled() const;
 
+    /** This method allows Plasma to enable and disable the adaptive
+     * transparency option of the panel, which allows user to decide
+     * whether the panel should be always transparent, always opaque
+     * or only opaque when a window is maximized.
+     * The configuration in the metadata.desktop file of the theme
+     * could look like this (for a lighter background):
+     * \code
+     * [AdaptiveTransparency]
+     * enabled=true
+     * \endcode
+     * @return Whether or not to enable the adaptive transparency
+     * @since 5.20
+     */
+    bool adaptiveTransparencyEnabled() const;
+
     /** This method allows Plasma to set a background contrast effect
      * for a given theme, improving readability. The value is read
      * from the "contrast" key in the "ContrastEffect" group in the
@@ -427,7 +442,7 @@ public:
      * You can use it like this in QML Items:
      * \code
      * Item {
-     *     width: theme.mSize(theme.defaultFont).height
+     *     width: PlasmaCore.Theme.mSize(PlasmaCore.Theme.defaultFont).height
      *     height: width
      * }
      * \endcode
@@ -441,6 +456,8 @@ public:
 
     QString backgroundPath(const QString &image) const;
 
+    static QPalette globalPalette();
+
 Q_SIGNALS:
     /**
      * Emitted when the user changes the theme. Stylesheet usage, colors, etc. should
@@ -468,4 +485,3 @@ private:
 } // Plasma namespace
 
 #endif // multiple inclusion guard
-
